# coding: utf-8

import pyglet
from pyglet.gl import *
from pyglet.math import Mat4
from pyglet.graphics.shader import Shader, ShaderProgram
import random
import math
import numpy as np

wsize = 1000

config = pyglet.gl.Config(double_buffer=True)
win = pyglet.window.Window(wsize,wsize,config=config,resizable=True)
win.set_caption('Ideal chain')
win.set_fullscreen(False)

batch = pyglet.graphics.Batch()

end_points=[ ]

lines = [ ]
def draw_chain():
    for line in lines:
        line.delete()
    lines.clear()    
    x=0.0
    y=0.0
    for _ in range(100):
        a = random.uniform(0,math.pi*2)
        dx = math.cos(a)
        dy = math.sin(a)
        line = pyglet.shapes.Line(x, y, x+dx, y+dy, width=0.2, color=(200, 200, 256), batch=batch)
        lines.append(line)
        x += dx
        y += dy
    point = pyglet.shapes.Circle(x, y, 0.2, color=(255, 0, 0, 64), batch=batch)
    end_points.append(point)

loop_cnt=0
timer_running = False
def loop(dt):
    global loop_cnt,timer_running
    loop_cnt += 1
    if loop_cnt>10000:
        pyglet.clock.unschedule(loop)
        timer_running = False
    draw_chain()
    return

@win.event
def on_resize(width, height):
    glViewport(0, 0, width, height)
    ratio = height/width
    win.projection = Mat4.orthogonal_projection(-40, 40, -40*ratio, 40*ratio, -255, 255)
    return pyglet.event.EVENT_HANDLED

@win.event
def on_draw():
    glClear(GL_COLOR_BUFFER_BIT)
    glClearColor(1,1,1,1)
    batch.draw()

@win.event
def on_key_press(symbol, modifiers):
    global timer_running
    if timer_running:
        pyglet.clock.unschedule(loop)
        timer_running=False
    else:
        pyglet.clock.schedule_interval(loop, 0.1)
        timer_running=True        

glEnable(GL_BLEND)
glBlendFunc(GL_SRC_ALPHA,GL_ONE_MINUS_SRC_ALPHA)
on_resize(*win.size)
    
pyglet.clock.schedule_interval(loop, 0.1)
timer_running=True

pyglet.app.run()
